@@ -1,9 +1,9 @@
 #
-# $Id: Split.pm,v 0.49 2004/01/07 20:43:35 sts Exp $
+# $Id: Split.pm,v 0.5 2004/01/08 07:31:12 sts Exp $
 
 package Dir::Split;
 
-our $VERSION = '0.49';
+our $VERSION = '0.5';
 
 use 5.6.1;
 use strict 'vars';
@@ -248,7 +248,7 @@ sub split {
         $o->_sort_files() if $o->{'mode'} eq 'num';
         $o->_suffix();
         $o->_move();
-        $o->_traversed_rm_dir() if ${__PACKAGE__.'::traverse'};
+        $o->_traversed_rm_dir() if $traverse;
 
         $Ret_status = FAILURE if %failure;
     }
@@ -342,7 +342,7 @@ sub _sanity_input {
 sub _gather_files {
     my $o = $_[0];
 
-    if (${__PACKAGE__.'::traverse'}) {
+    if ($traverse) {
         $o->_traverse(\@Dirs, \@Files);
     }
     else {
@@ -365,7 +365,7 @@ sub _sort_files {
     if ($o->{'f_sort'} eq '+' || $o->{'f_sort'} eq '-') {
         # preserve case-sensitive filenames.
         foreach (@Files) {
-           $F_names_case{lc($_)} = $_;
+            $F_names_case{lc($_)} = $_;
         }
         @Files = map lc, @Files;
 
@@ -446,7 +446,7 @@ sub _suffix_char {
     my $o = $_[0];
 
     foreach my $file (@Files) {
-        if (${__PACKAGE__.'::traverse'}) { $_ = basename($file) }
+        if ($traverse) { $_ = basename($file) }
         else { $_ = $file }
         s/\s//g if /\s/; # whitespaces
         ($_) = /^(.{$o->{'length'}})/;
@@ -540,8 +540,8 @@ sub _mkpath {
     $Path = File::Spec->catfile($o->{'target'}, "$o->{'ident'}$o->{'sep'}$suffix");
 
     return if -e $Path;
-    mkpath $Path, $o->{'verbose'} or
-      croak qq~Dir $Path could not be created: $!~;
+    mkpath $Path, $o->{'verbose'}
+      or croak qq~Dir $Path could not be created: $!~;
 
     $track{'target'}{'dirs'}++;
 }
@@ -557,7 +557,7 @@ sub _cp_unlink {
     my ($o, $file) = @_;
 
     my $path_target;
-    if (${__PACKAGE__.'::traverse'}) {
+    if ($traverse) {
         $path_target = File::Spec->catfile($Path, basename($file));
     }
     else {
@@ -576,8 +576,8 @@ sub _cp_unlink {
     }
     $track{'target'}{'files'}++;
 
-    if (${__PACKAGE__.'::traverse'}) {
-        return unless ${__PACKAGE__.'::traverse_unlink'};
+    if ($traverse) {
+        return unless $traverse_unlink;
     }
 
     unless (unlink $file) {
@@ -630,9 +630,8 @@ __DATA__
 sub _traverse {
     my ($o, $dirs_ref, $files_ref) = @_;
 
-    my ($count, @dirs, $eval, @eval, @files,
-        $limit, @stack);
-    $count = 0;
+    my (@eval, @stack, @dirs, @files);
+    my $depth = 0;
 
     $o->_dir_read($o->{'source'}, \@eval);
     @eval =
@@ -641,6 +640,7 @@ sub _traverse {
 
     TRAVERSE:
     while (@eval) {
+        my $eval;
         if (-d $eval[0]) {
             $eval = shift @eval;
             push @dirs, $eval;
@@ -662,7 +662,8 @@ sub _traverse {
         }
 
         unless (@eval) {
-            if (++$count == ${__PACKAGE__.'::traverse_depth'}) {
+            no warnings;
+            if (++$depth == $traverse_depth) {
                 last TRAVERSE;
             }
             @eval = @stack;
@@ -681,9 +682,9 @@ sub _traverse {
 #
 
 sub _traversed_rm_dir {
-    if (${__PACKAGE__.'::traverse_rmdir'}) {
-        if (!${__PACKAGE__.'::traverse_depth'}
-          && ${__PACKAGE__.'::traverse_unlink'}) {
+    if ($traverse_rmdir) {
+        if (!$traverse_depth
+          && $traverse_unlink) {
             foreach (@Dirs) {
                 rmtree($_, 1, 1);
             }
